function S = plus(A,B)

% S = PLUS(A,B)     
%
% Adds data in timescale objects and produces a new timescale object holding the sum. 
%
% INPUTS:
% A,B       Timescale objects to add together. A or B can be a scalar as well.
%
%       
% OUTPUTS: 
% S         Timescale object holding the sum.
%

% Ian Gravagne, 12/29/03 Baylor University

if(nargin ~= 2)
    error('Requires 2 arguments.');
end

if( (~isa(A,'timescale') & ~isnumeric(A)) | (~isa(B,'timescale') & ~isnumeric(B)) )
    error('Only accepts timescale objects and scalars as inputs.');
end

S = timescale;

if(isa(A,'timescale') & isa(B,'timescale'))
    if(incompatible(A,B))
        error('Timescale objects have different length or types of data (continuous or discrete).')
    end
    S.type = A.type;
    S.data = A.data + B.data;
elseif(isa(A,'timescale'))
    S.type = A.type;
    S.data = A.data + B(1);
elseif(isa(B,'timescale'))
    S.type = B.type;
    S.data = A(1) + B.data;
end
